==> uberfire-parent-2.12.0.Final-project-sources.tar.gz: uberfire-parent-2.12.0.Final/uberfire-extensions/uberfire-wires/uberfire-wires-core/uberfire-wires-core-grids/src/main/java/org/uberfire/ext/wires/core/grids/client/widget/grid/renderers/themes/impl/KIEColours.java <==
/*
 * Copyright 2018 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.uberfire.ext.wires.core.grids.client.widget.grid.renderers.themes.impl;

/**
 * Shared colours for KIE grids. See https://issues.jboss.org/browse/DROOLS-3151
 */
public class KIEColours {

    public static final String HEADER_BACKGROUND_WHITE = "#FFFFFF";

    public static final String HEADER_BACKGROUND_LIGHT_GREY = "#EDEDED";

    public static final String HEADER_BACKGROUND_LIGHT_BLUE = "#DEF3FF";

    public static final String HEADER_BACKGROUND_DARK_BLUE = "#BEE1F4";

    public static final String TABLE_GRID = "#BBBBBB";

    public static final String TABLE_TEXT = "#030303";

    public static final String CELL_CONTENT = "#FFFFFF";

    public static final String CELL_FOCUS = "#0088CE";

    public static final String CELL_ERROR_FOCUS = "#CC0000";

    public static final String CELL_ERROR_BACKGROUND = "#FFE6E6";

    public static final String PLACEHOLDER_COLOR = "#757575";
}

==> uberfire-parent-2.22.0.Final-project-sources.tar.gz: uberfire-parent-2.22.0.Final/uberfire-extensions/uberfire-wires/uberfire-wires-core/uberfire-wires-core-grids/src/main/java/org/uberfire/ext/wires/core/grids/client/widget/grid/renderers/themes/impl/KIEColours.java <==
/*
 * Copyright 2018 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.uberfire.ext.wires.core.grids.client.widget.grid.renderers.themes.impl;

/**
 * Shared colours for KIE grids. See https://issues.jboss.org/browse/DROOLS-3151
 */
public class KIEColours {

    public static final String HEADER_BACKGROUND_WHITE = "#FFFFFF";

    public static final String HEADER_BACKGROUND_LIGHT_GREY = "#EDEDED";

    public static final String HEADER_BACKGROUND_LIGHT_BLUE = "#DEF3FF";

    public static final String HEADER_BACKGROUND_DARK_BLUE = "#BEE1F4";

    public static final String TABLE_GRID = "#BBBBBB";

    public static final String TABLE_TEXT = "#030303";

    public static final String CELL_CONTENT = "#FFFFFF";

    public static final String CELL_FOCUS = "#0088CE";

    public static final String CELL_ERROR_FOCUS = "#8B0000";

    public static final String CELL_ERROR_BACKGROUND = "#FFE6E6";

    public static final String PLACEHOLDER_COLOR = "#757575";
}
